#!/bin/sh
# Search edict dictionary for the specified word.
# See http://www.dgs.monash.edu.au/~jwb/edict.html about edict.
#

progname=$0
version=1.0.0
usage="\
Usage: $progname
Read a word from standard input, and search edict dictionary for the word.
Write the result to standard output.
  -f, --edict edict-path     specify edict dictionary path 
  -h, --help                 print this help and exit
  -v, --version              print version information and exit"

# edict dictionary path.
EDICT=/usr/share/edict/edict
# grep command path.
GREP=/usr/bin/grep

# Option processing
while [ "$1" != "" ]
do
	case "$1" in
	-f | --edict) 
		shift
		test $# -eq 0 && { echo "$usage"; exit 0; }
		EDICT="$1" ;;
	-h | --help) 
		echo "$usage"; exit 0;;
	-v | --version | --v*)
		echo "$progname $version"; exit 0;;
	--) # Stop option processing.
		shift; break ;;
	*)	
		break ;;
	esac
	shift	
done

# Check necessary files
if [ ! -f $EDICT ]
then
	echo "Warning:"
	echo "$EDICT not found"
	exit 0
fi

if [ ! -x $GREP ]
then
	echo "Warning:"
	echo "You can't execute $GREP."
	exit 0
fi

# target word from standard input
read target
if [ -z $target ]
then
	exit 0
fi

# Search edict dictionary for the target word
if $GREP -i "[/ ]$target[/ ]" $EDICT
then
	exit 0
elif $GREP -w "\[$target\]" $EDICT
then
	exit 0
elif $GREP "^$target " $EDICT
then
	exit 0
elif $GREP -i "$target" $EDICT
then
	exit 0
else
	exit 1
fi



