#!/bin/sh
# Search engdic dictionary for the specified word.
#

progname=$0
version=1.0.0
usage="\
Usage: $progname
Read a word from standard input, and search engdic dictionary for the word.
Write the result to standard output.
  -f, --engdic engdic-path   specify engdic dictionary path 
  -h, --help                 print this help and exit
  -v, --version              print version information and exit"

# edic dictionary path.
ENGDIC=/usr/share/engdic
# grep command path.
GREP=`which zgrep`

# Option processing
while [ "$1" != "" ]
do
	case "$1" in
	-f | --engdic) 
		shift
		test $# -eq 0 && { echo "$usage"; exit 0; }
		ENGDIC="$1" ;;
	-h | --help) 
		echo "$usage"; exit 0;;
	-v | --version | --v*)
		echo "$progname $version"; exit 0;;
	--) # Stop option processing.
		shift; break ;;
	*)	
		break ;;
	esac
	shift	
done

# Check necessary files
if [ ! -d $ENGDIC ]
then
	echo "Warning:"
	echo "$ENGDIC not found"
	exit 0
fi

if [ ! -x $GREP ]
then
	echo "Warning:"
	echo "You can't execute $GREP."
	exit 0
fi

# target word from standard input
read WORD
if [ -z $WORD ]
then
       exit 0
fi

# Search engdic dictionary for the target word

DIC=`echo $WORD | cut -b 1 | tr \[:upper:\] \[:lower:\]`
if [ "$DIC" = "a" -o "$DIC" = "b" -o "$DIC" = "c" -o "$DIC" = "d" \
  -o "$DIC" = "e" -o "$DIC" = "f" -o "$DIC" = "g" -o "$DIC" = "h" \
  -o "$DIC" = "i" -o "$DIC" = "j" -o "$DIC" = "k" -o "$DIC" = "l" \
  -o "$DIC" = "m" -o "$DIC" = "n" -o "$DIC" = "o" -o "$DIC" = "p" \
  -o "$DIC" = "q" -o "$DIC" = "r" -o "$DIC" = "s" -o "$DIC" = "t" \
  -o "$DIC" = "u" -o "$DIC" = "v" -o "$DIC" = "w" -o "$DIC" = "x" \
  -o "$DIC" = "y" -o "$DIC" = "z" ] ; then

        $GREP -ihw ^"$WORD" $ENGDIC/$DIC.dic| awk -F':' '\
	{print "[ "$1"]"}{print $2}' | fmt -w 74| more
        exit 0
else
        $GREP -hw $WORD $ENGDIC/*| awk -F':' '\
	{print "[ "$1"]"}{print $2}' | fmt -w 74| more
        exit 0
fi
exit 1
